@@ -7,6 +7,11 @@ from htools.core import shell
 from htools.structures import IndexedDict
 
 
+# Have to define this at the top so we can reference it in functions. We later
+# make it available as part of C.
+git_clone_url = 'https://github.com/hdmamin/jabberwocky.git'
+
+
 def resolve_root():
     """Get the project root directory. This directory should contain the 'data'
     subdir. If working from the main git repo (i.e. what I've been doing for
@@ -46,7 +51,8 @@ def clone_or_pull_prompts(path='~/.jabberwocky', update=False):
             code = 0
     else:
         print(f'{Path} is not an existing directory. Cloning from github...')
-        code, *_ = shell(f'git clone {C.git_clone_url} {path}')
+        # Must reference the global git clone var var here.
+        code, *_ = shell(f'git clone {git_clone_url} {path}')
     if code:
         raise RuntimeError('Cloning/pulling prompts failed.')
     return path
@@ -93,7 +99,9 @@ class C:
     root = resolve_root()
     data_dir = root/'data'
     prompt_dir = data_dir/'prompts'
-    git_clone_url = 'https://github.com/hdmamin/jabberwocky.git'
+    # Make this available as an attribute now. Need to keep global var to use
+    # in functions in this module which have to execute before this line.
+    git_clone_url = git_clone_url
     # This contains a dict generated by scripts/s01_fetch_sample_responses.py.
     # Contains more variants of responses (see script docstring for details).
     all_mocks_path = root/'data/misc/gooseai_sample_responses.pkl'
